<?php
/**
* Templates hook
*
* @author nouthemes [nouthemes@gmail.com] 
* @since 1.0
*/ 

class Noubakery_Theme_Templates
{

	public static function init()
	{
		add_action('noubakery_header', array( __CLASS__, 'hook_header' ), 10 );
		add_action('noubakery_footer', array( __CLASS__, 'hook_footer' ), 10 );
		add_action('noubakery_heading', array( __CLASS__, 'panel_heading' ), 10 );
		add_filter('the_content', array(__CLASS__, 'filter_lazyload'));
		add_filter('the_content', array(__CLASS__, 'filter_html_tag'));
		add_filter('widget_nav_menu_args', array(__CLASS__, 'nav_menu_args'), 999 );
		add_action('noubakery_pagination', array( __CLASS__, 'blog_pagination' ), 10 );
		add_filter('get_archives_link',array(__CLASS__, 'custom_archives_link'));
		add_filter('wp_list_categories',array(__CLASS__, 'wp_list_categories_output'));
		add_filter('widget_tag_cloud_args',array(__CLASS__, 'widget_tag_cloud_args'));
		add_filter( 'post_thumbnail_html', array(__CLASS__, 'remove_width_attribute'), 10 );
		add_filter( 'image_send_to_editor', array(__CLASS__, 'remove_width_attribute'), 10 );
		add_filter( 'body_class', array(__CLASS__, 'body_class') );
	}

	public static function body_class( $classes ) {
	    return array_merge( $classes, array( 'page-init' ) );
	}

	public static function remove_width_attribute( $html ) {
	   $html = preg_replace( '/(width|height)="\d*"\s/', "", $html );
	   return $html;
	}

	public static function filter_html_tag($content){
		$content = str_replace('<tt>', '', $content);
		$content = str_replace('</tt>', '', $content);
		$content = str_replace('<big>', '<strong>', $content);
		$content = str_replace('</big>', '</strong>', $content);
		$content = str_replace('<acronym', '<abbr', $content);
		$content = str_replace('</acronym>', '</abbr>', $content);
		return $content;
	}

	public static function nav_menu_args($nav_menu_args){
		$nav_menu_args['menu_class'] = 'ps-list--line';
        $nav_menu_args['container']  = false;
		return $nav_menu_args;
	}

	public static function widget_tag_cloud_args($args)
	{
		$args = array_merge(array('format' => 'list'), $args);
		return $args;
	}

	public static function wp_list_categories_output($link)
	{
		$link = str_replace('</a> (', '&nbsp;<span>(', $link);
		$link = str_replace(')', ')</span></a>', $link);
		return $link;
	}

	public static function custom_archives_link($link)
	{
		$link = str_replace('</a>&nbsp;(', '&nbsp;<span>(', $link);
		$link = str_replace(')</li>', ')</span></a></li>', $link);
		return $link;
	}

	public static function blog_pagination($blog)
	{	
		global $wp_query;

		if ( $wp_query->max_num_pages <= 1 ) {
			return;
		}

		?>
		<div class="ps-pagination">
			<?php
				echo paginate_links( apply_filters( 'woocommerce_pagination_args', array(
					'base'         => esc_url_raw( str_replace( 999999999, '%#%', remove_query_arg( 'add-to-cart', get_pagenum_link( 999999999, false ) ) ) ),
					'format'       => '',
					'add_args'     => false,
					'current'      => max( 1, get_query_var( 'paged' ) ),
					'total'        => $wp_query->max_num_pages,
					'prev_text'    => '<i class="fa fa-arrow-left"></i>',
					'next_text'    => '<i class="fa fa-arrow-right"></i>',
					'type'         => 'list',
					'end_size'     => 3,
					'mid_size'     => 3
				) ) );
			?>
		</div>
		<?php
	}

	public static function hook_header()
	{
		if ( !is_404() ) {
			$header_style = noubakery_header_style();
			$logo = noubakery_logo();
			$header_class = $header_style > 1 ? 'header header--'.$header_style : 'header';
			if($header_style == 3){
				$header_class = 'header header--new';
			}
			?>
			
			<?php get_template_part('template-parts/header/search_bar');?>
			<header class="<?php echo esc_attr($header_class);?>" data-responsive="1199">
				<?php get_template_part('template-parts/header/top');?>
				<?php 
				if($header_style == 3){
					get_template_part('template-parts/header/left');
				}else{
					get_template_part('template-parts/header/bottom');
				}?>
			</header>

			<?php $shop_settings = noubakery_shop_style();?>

			<?php $menu_bottom_mobile_enable = noubakery_noubakery_cs_get_option('noubakery_menu_bottom_mobile_enable');?>
			<?php if($menu_bottom_mobile_enable):?>
			<nav class="ps-mobile-nav hidden-lg hidden-md">
		      	<ul class="ps-list--footer">
		      		<?php if(!empty($shop_settings['wishlist'])):?>
		        	<li><a href="<?php echo esc_url(get_permalink(noubakery_noubakery_cs_get_option('noubakery_shop_wishlist_page_id')));?>"><i class="ps-icon--heart"></i><span><?php esc_html_e('Wishlist', 'noucake');?></span></a></li>
		        	<?php endif;?>

		        	<li><a href="<?php echo esc_url(get_permalink(get_option('woocommerce_myaccount_page_id')));?>"><i class="ps-icon--profile"></i><span><?php esc_html_e('Account', 'noucake');?></span></a></li>

		        	<li><a class="ps-search-btn" href="#"><i class="ps-icon--search"></i><span><?php esc_html_e('Search', 'noucake');?></span></a></li>

		        	<?php if(class_exists('Woocommerce')):?>
		        		<li><a class="ps-cart-count" href="<?php echo esc_url(get_permalink(get_option('woocommerce_cart_page_id')));?>"><i class="ps-icon--shopping-cart"></i><span class="quantity"><i class="mobile_cart_content"><?php echo intval(WC()->cart->get_cart_contents_count());?></i></span><span><?php esc_html_e('Cart', 'noucake');?></span></a></li>
		        	<?php endif;?>
		      	</ul>
		    </nav>
		    <?php endif;?>
			<?php
		}	 
	}

	public static function hook_footer()
	{
		if ( !is_404() ) {
			$loader = noubakery_noubakery_cs_get_option('noubakery_loader');
			$bakery_options = get_option(NOUBAKERY_THEME_CS_OPTION);
			$widget_col = !empty($bakery_options['noubakery_widget_footer_col']) ? $bakery_options['noubakery_widget_footer_col'] : 4;
			?>	
				<div id="back2top"><i class="fa fa-angle-up"></i></div>
	    		<?php if($loader):?><div class="loader"></div><?php endif;?>
	    		<?php get_template_part('template-parts/footer/top');?>
	    		<footer class="ps-footer">
			        <div class="container">
			          <div class="row">
			          		<?php 
			          		for ($i=1; $i <= $widget_col; $i++) { 
			          			if( is_active_sidebar('footer-sidebar-'.$i) ){
			          				echo '<div class="col-lg-'.intval(12/$widget_col).' col-md-'.intval(12/$widget_col).' col-sm-6 col-xs-12">';
			          				dynamic_sidebar('footer-sidebar-'.$i);
			          				echo '</div>';
			          			}
			          		}
			          		?>
			          </div>
			        </div>
			    </footer>

			    <?php if(class_exists('Woocommerce')):?>
			    <div class="modal-popup mfp-with-anim mfp-hide" id="quickview-modal" tabindex="-1">
				  	<button class="modal-close"><i class="fa fa-remove"></i></button>
				  	<div class="ps-product-modal ps-product--detail clearfix">
				  		<span class="cart-loading"><i class="fa fa-spinner fa-spin"></i></span>
				  		<?php 
				  		$args = array(
							'post_type'      => 'product',
							'posts_per_page' => 1,
							'post_status'    => 'publish',
						);
						$products = new WP_Query($args);
						if ( $products->have_posts() ) :
							while($products->have_posts()): $products->the_post();
							$all_images = noubakery_product_images(get_the_ID());
							?>
							<div id="product-<?php the_ID(); ?>" <?php post_class(); ?>>
								<div class="col-lg-5 col-md-5 col-sm-12 col-xs-12 ">
					                <div class="ps-product__thumbnail">
					                  <div class="quickview--main" data-owl-auto="true" data-owl-loop="false" data-owl-speed="10000" data-owl-gap="0" data-owl-nav="false" data-owl-dots="false" data-owl-animate-in="" data-owl-animate-out="" data-owl-item="1" data-owl-item-xs="1" data-owl-item-sm="1" data-owl-item-md="1" data-owl-item-lg="1" data-owl-nav-left="&lt;i class=&quot;fa fa-angle-left&quot;&gt;&lt;/i&gt;" data-owl-nav-right="&lt;i class=&quot;fa fa-angle-right&quot;&gt;&lt;/i&gt;">
						                    <?php
												if ( count($all_images) > 0 ) {

													foreach ($all_images as $id) {
														$images = wp_get_attachment_image_src($id, 'noubakery_458x493');
														if($images){
															?>
															<div class="ps-product__image">
											                    <img src="<?php echo esc_attr($images[0]);?>" alt="<?php the_title(); ?>"/>
											                </div>
															<?php
														}
													}
													
												} else {
													echo apply_filters( 'woocommerce_single_product_image_html', sprintf( '<div class="ps-product__image"><img src="%s" alt="%s" class="gallery-image"/></div>', wc_placeholder_img_src(), __( 'Placeholder', 'noucake' ) ), get_the_ID() );
												}

												
											?>
					                  </div>
					                  <?php if ( count($all_images) > 0 ) {?>
					                  <div class="quickview--thumbnail" data-owl-auto="true" data-owl-loop="false" data-owl-speed="10000" data-owl-gap="20" data-owl-nav="false" data-owl-dots="false" data-owl-animate-in="" data-owl-animate-out="" data-owl-item="4" data-owl-item-xs="2" data-owl-item-sm="3" data-owl-item-md="4" data-owl-item-lg="4" data-owl-nav-left="&lt;i class=&quot;fa fa-angle-left&quot;&gt;&lt;/i&gt;" data-owl-nav-right="&lt;i class=&quot;fa fa-angle-right&quot;&gt;&lt;/i&gt;">
					                  	<?php
											if ( count($all_images) > 0 ) {

												foreach ($all_images as $id) {
													$images = wp_get_attachment_image_src($id, 'noubakery_100x107');
													if($images){
														?>
														<img src="<?php echo esc_attr($images[0]);?>" alt="<?php echo esc_attr($images[0]);?>"/>
														<?php
													}
												}
												
											}
											
										?>
					                  </div>
					                  <?php }?>
					                </div>
					            </div>
					            <div class="col-lg-7 col-md-7 col-sm-12 col-xs-12 ">
					                <header>
					                  <h3 class="ps-product__name"><?php the_title();?></h3>
					                  <?php
					                  woocommerce_template_single_rating();
						    		  woocommerce_template_single_price();
						    		  woocommerce_template_single_meta();
						    		  woocommerce_template_single_add_to_cart();
					                  ?>
					                </header>
					                <?php
										/**
										 * woocommerce_single_product_summary hook.
										 */
										do_action( 'woocommerce_single_product_summary' );
									?>
					            </div>
					        </div>
							<?php
							endwhile;
						endif;wp_reset_postdata();
				  		?>
				  	</div>
				</div>
				<?php endif;?>

				<?php if(!is_user_logged_in() && class_exists('Newsletter')){get_template_part('template-parts/popup');}?>
			<?php 
		}
	}

	public static function panel_heading()
	{
		$show_title = true;
		$show_breadcrumb = true;
		$show = noubakery_noubakery_cs_get_option('noubakery_heading_display');
		$panel_background = noubakery_noubakery_cs_get_option('noubakery_panel_background', esc_url(NOUBAKERY_IMG.'/hero/01.jpg'));
		$panel_title = noubakery_noubakery_cs_get_option('noubakery_title_enable');
		$panel_breadcrumb = noubakery_noubakery_cs_get_option('noubakery_panel_breadcrumb');

		if(empty($panel_title)){
			$show_title = false;
		}

		if(empty($panel_breadcrumb)){
			$show_breadcrumb = false;
		}

		$current_id = noubakery_get_current_id() ;
		if($current_id){
			$meta = get_post_meta($current_id, 'noubakery_layout_settings', true);
			
			if(isset($meta['post_title_enable']) && $meta['post_title_enable'] == 2){
				$show_title = false;
			}

			if(isset($meta['panel_breadcrumb']) && $meta['panel_breadcrumb'] == 2){
				$show_breadcrumb = false;
			}

			if(isset($meta['post_title_enable']) && $meta['post_title_enable'] == 1){
				$show_title = true;
			}

			if(isset($meta['panel_breadcrumb']) && $meta['panel_breadcrumb'] == 1){
				$show_breadcrumb = true;
			}

			if(!empty($meta['panel_background'])){
				$panel_background = $meta['panel_background'];
			}

			if(!empty($meta['display_heading']) && $meta['display_heading'] == 2){
				$show = false;
			}
		}

		if(is_tax()){
			$queried_object = get_queried_object();
			$term_id = $queried_object->term_id;
			$meta = noubakery_get_term_meta($term_id, 'noubakery_layout_settings', true);
			
			if(!empty($meta['display_heading']) && $meta['display_heading'] == 2){
				$show = false;
			}

			if(!empty($meta['post_title_enable']) && $meta['post_title_enable'] == 2){
				$show_title = false;
			}

			if(!empty($meta['panel_breadcrumb']) && $meta['panel_breadcrumb'] == 2){
				$show_breadcrumb = false;
			}

			if(!empty($meta['post_title_enable']) && $meta['post_title_enable'] == 1){
				$show_title = true;
			}

			if(!empty($meta['panel_breadcrumb']) && $meta['panel_breadcrumb'] == 1){
				$show_breadcrumb = true;
			}

			if(!empty($meta['panel_background'])){
				$panel_background = $meta['panel_background'];
			}
		}
		
		if(is_home()){
			$show_breadcrumb = false;
		}

		if($show):
		?>
		<div class="ps-section--hero">
			<img src="<?php echo esc_attr($panel_background);?>" alt="<?php noubakery_get_title();?>">
	        <div class="ps-section__content text-center">
	          <?php if($show_title):?>
	          	<h3 class="ps-section__title"><?php noubakery_get_title();?></h3>
	          <?php endif;?>

	          <?php if($show_breadcrumb):?>
	          <div class="ps-breadcrumb">
	            <?php noubakery_breadcrumbs();?>
	          </div>
	          <?php endif;?>

	        </div>
	    </div>
		<?php
		endif;
	}

	public static function filter_lazyload($content) {
		$enable_lazy = noubakery_noubakery_cs_get_option('noubakery_lazy');
		if($enable_lazy){
	    	return preg_replace_callback('/(<\s*img[^>]+)(src\s*=\s*"[^"]+")([^>]+>)/i', 'noubakery_preg_lazyload', $content);
	    }else{
	    	return $content;
	    }	
	}

}
?>