<?php 
defined( 'ABSPATH' ) OR exit;
/**
 * Helper
 *
 * @package Bakery
 * @since 1.0
 * @author nouthemes [nouthemes@gmail.com]
 */

/**
 *
 * Get option
 *
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if ( ! function_exists( 'noubakery_noubakery_cs_get_option' ) ) {
  function noubakery_noubakery_cs_get_option( $option_name = '', $default = '' ) {

    $options = apply_filters( 'noubakery_noubakery_cs_get_option', get_option( NOUBAKERY_THEME_CS_OPTION ), $option_name, $default );

    if( ! empty( $option_name ) && ! empty( $options[$option_name] ) ) {
      return $options[$option_name];
    } else {
      return ( ! empty( $default ) ) ? $default : null;
    }

  }
}

/**
 *
 * Get customize option
 *
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if ( ! function_exists( 'noubakery_cs_get_customize_option' ) ) {
  function noubakery_cs_get_customize_option( $option_name = '', $default = '' ) {

    $options = apply_filters( 'noubakery_cs_get_customize_option', get_option( NOUBAKERY_THEME_CS_CUSTOMIZE ), $option_name, $default );

    if( ! empty( $option_name ) && ! empty( $options[$option_name] ) ) {
      return $options[$option_name];
    } else {
      return ( ! empty( $default ) ) ? $default : null;
    }

  }
}

/**
* Current page ID
*
* @author nouthemes [nouthemes@gmail.com]
* @since 1.0
* @code Nam
*/
if(!function_exists('noubakery_get_current_id')){
	function noubakery_get_current_id() 
	{

	    $object_id = get_queried_object_id();

	    if ( ( get_option( 'show_on_front' ) && get_option( 'page_for_posts' ) && is_home() ) || ( get_option( 'page_for_posts' ) && is_archive() && ! is_post_type_archive() && ! is_tax() ) && ! ( is_tax( 'product_cat' ) || is_tax( 'product_tag' ) ) || ( get_option( 'page_for_posts' ) && is_search() ) ) {
	        
	        $page_ID = get_option( 'page_for_posts' );

	    } else {

	        if ( isset( $object_id ) ) {
	            $page_ID = $object_id;
	        }

	        if ( ! is_singular() ) {
	            $page_ID = false;
			}
			
			if(function_exists('is_shop')){
				if(is_shop()){
					$page_ID = wc_get_page_id( 'shop' );
				}
			}
	    }

	    return $page_ID;

	}
}	



/**
* Sync from customizer vs theme options
* 
* @author nouthemes [nouthemes@gmail.com]
* @since 1.0
* @return url
* @code Nam
*/
if(!function_exists('noubakery_theme_option')){
	function noubakery_theme_option($key, $default = '')
	{	
		$customizer = noubakery_cs_get_customize_option($key);
		$options = noubakery_noubakery_cs_get_option('noubakery_'.$key, $default);
		$option_value = !empty($customizer) ? $customizer : $options;
	    return apply_filters('noubakery_theme_option', $option_value);
	}
}

/**
* Get src loading image
* 
* @author nouthemes [nouthemes@gmail.com]
* @since 1.0
* @return url
* @code Nam
*/
if(!function_exists('noubakery_theme_image_loading_src')){
	function noubakery_theme_image_loading_src()
	{
	    return apply_filters('noubakery_default_loading_img', NOUBAKERY_IMG . '/ajax-loader.gif');
	}
}

/**
 * Breadcrumbs
 *
 * @package Bakery
 * @since 1.0
 * @author nouthemes [nouthemes@gmail.com]
 */
if(!function_exists('noubakery_breadcrumbs')){
	function noubakery_breadcrumbs()
	{
		if( class_exists('Woocommerce') ){
			woocommerce_breadcrumb();
		}
	}
}

if(!function_exists('noubakery_generator_image')){
	function noubakery_generator_image($src, $width = '', $height = '', $class = array()){
		$enable_lazy = noubakery_noubakery_cs_get_option('noubakery_lazy');
		if($enable_lazy){
			$loading_src = noubakery_theme_image_loading_src();
			$img = '<img src="'.esc_attr($loading_src).'" class="lazy '.esc_attr(join(' ', $class)).'" data-original="'.esc_attr( $src ).'" width="'.esc_attr( $width ).'" height="'.esc_attr( $height ).'" alt="'.esc_attr(get_the_title()).'"/>';
		}else{
			$img = '<img src="'.esc_attr($src).'" class="'.esc_attr(join(' ', $class)).'" alt="'.esc_attr(get_the_title()).'"/>';
		}

		return $img;
	}
}


/**
 * Get post thumbnail
 *
 * @package Bakery
 * @since 1.0
 * @author nouthemes [nouthemes@gmail.com]
 */
if(!function_exists('noubakery_post_thumbnail')){
	function noubakery_post_thumbnail( $post_id = -1, $size = 'thumbnail', $class = array() )
	{
		
		global $post;

		if($post_id == -1){ //if there is no ID
			$post_id = get_the_ID();
		}elseif( is_string($post_id) && !is_numeric($post_id) ){ //if it's only thumbnail size
			$size = $post_id;
			$post_id = get_the_ID();
		}

		$src = noubakery_theme_image_loading_src();
		$img = '';

		if( has_post_thumbnail( $post_id ) ){
			$post_thumbnail_id = get_post_thumbnail_id( $post_id );
			$image_attributes = wp_get_attachment_image_src( $post_thumbnail_id, $size );
			
			try {
				$img = noubakery_generator_image($image_attributes[0], $image_attributes[1], $image_attributes[2], $class);
			} catch (\Throwable $th) {}
		}

		echo wp_kses(
			$img, 
			array(
				'img' => array(
					'src' => array(),
					'class' => array(), 
					'data-original' => array(),
					'width' => array(),
					'height' => array(),
					'alt' => array(), 
					)));
	}
}


/**
 * Get image by thumbnail id
 *
 * @package Bakery
 * @since 1.0
 * @author nouthemes [nouthemes@gmail.com]
 */
if(!function_exists('noubakery_get_image_by_id')){
	function noubakery_get_image_by_id($id, $size = 'thumbnail', $class = array()){
		$src = noubakery_theme_image_loading_src();
		$image_attributes = wp_get_attachment_image_src( $id, $size );
		$img = noubakery_generator_image($image_attributes[0], $image_attributes[1], $image_attributes[2], $class);
		echo wp_kses(
			$img, 
			array(
				'img' => array(
					'src' => array(),
					'class' => array(), 
					'data-original' => array(),
					'width' => array(),
					'height' => array(),
					'alt' => array(), 
					)));
	}
}

/**
 * Get default email
 *
 * @package Bakery
 * @since 1.0
 * @author nouthemes [nouthemes@gmail.com]
 */
if(!function_exists('noubakery_get_email')){
	function noubakery_get_email(){
		return noubakery_noubakery_cs_get_option('noubakery_email', get_option('admin_email'));
	}
}


/**
 * Mini cart - Woocommerce
 *
 * @package Bakery
 * @since 1.0
 * @author nouthemes [nouthemes@gmail.com]
 */
if(!function_exists('noubakery_mini_cart')){
	function noubakery_mini_cart(){
		if(class_exists('Woocommerce')):
			if ( WC()->cart->get_cart_contents_count() > 0 ):
			?>
			<a class="ps-cart__toggle" href="<?php echo esc_url(get_permalink(get_option('woocommerce_cart_page_id')));?>"><span><i><?php echo intval(WC()->cart->get_cart_contents_count());?></i></span><i class="ps-icon--shopping-cart"></i></a>
            <div class="ps-cart__listing">
              <div class="ps-cart__content">

                <?php 
		          foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ):
		            $_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
		            $product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

		            if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ):
		              $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
		        ?>

                <div class="ps-cart-item">
                	<?php
	                  echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
	                    '<a href="%s" class="ps-cart-item__close remove" title="%s" data-key="%s" data-product_id="%s" data-product_sku="%s"></a>',
	                    esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
	                    __( 'Remove this item', 'noucake' ),
	                    esc_attr( $cart_item_key ),
	                    esc_attr( $product_id ),
	                    esc_attr( $_product->get_sku() )
	                  ), $cart_item_key );
	                ?>
                  <div class="ps-cart-item__thumbnail">
                  	<?php
	                  $thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image('noubakery_60x65'), $cart_item, $cart_item_key );

	                  if ( ! $product_permalink ) {
	                    echo wp_kses_post($thumbnail);
	                  } else {
	                    printf( '<a href="%s">%s</a>', esc_url( $product_permalink ), wp_kses_post($thumbnail) );
	                  }
	                ?>
                  </div>
                  <div class="ps-cart-item__content">
                  	<?php
	                    if ( ! $product_permalink ) {
	                      echo apply_filters( 'woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key ) . '&nbsp;';
	                    } else {
	                      echo apply_filters( 'woocommerce_cart_item_name', sprintf( '<a class="ps-cart-item__title" href="%s">%s</a>', esc_url( $product_permalink ), $_product->get_title() ), $cart_item, $cart_item_key );
	                    }
	                ?>
                    <p>
                    	<span><?php esc_html_e('Quantity', 'noucake');?>:<i><?php echo intval($cart_item['quantity']);?></i></span>
                    	<span><?php esc_html_e('Total', 'noucake');?>: <?php
							echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
						?></span>
                    </p>
                  </div>
                </div>

                <?php endif;endforeach;?>

              </div>

              <div class="ps-cart__total">
                <p><?php esc_html_e('Number of items', 'noucake');?>:<span><?php echo intval(WC()->cart->get_cart_contents_count());?></span></p>
                <p><?php esc_html_e('Item Total', 'noucake');?>:<?php wc_cart_totals_subtotal_html(); ?></p>
              </div>

              <div class="ps-cart__footer">
              	<a class="ps-btn ps-btn--view-bag" href="<?php echo esc_url(get_permalink(get_option('woocommerce_cart_page_id')));?>"><?php esc_html_e('View bag', 'noucake');?></a>
              </div>
            </div>
			<?php else:?>
				<a class="ps-cart__toggle" href="<?php echo esc_url(get_permalink(get_option('woocommerce_cart_page_id')));?>"><span><i>0</i></span><i class="ps-icon--shopping-cart"></i></a>
		        <div class="ps-cart__listing ps-cart__listingempty">
              		<div class="ps-cart__content">
		          		<p class="ps-cart__conten__tempty"><?php esc_html_e('Cart is empty!', 'noucake');?></p>
		          	</div>
		        </div>  
				<?php
			endif;
		endif;
	}
}


/**
 * Get title
 *
 * @package Bakery
 * @since 1.0
 * @author nouthemes [nouthemes@gmail.com]
 */

if(!function_exists('noubakery_get_title')){
	function noubakery_get_title( $echo = true ) 
	{

	    $post_title     = '';
	   	$post_id 		= noubakery_get_current_id();

	    if($post_id){
	        $noubakery_meta = get_post_meta( $post_id, 'noubakery_layout_settings', true );
	        if ( isset($noubakery_meta['post_title']) && !empty($noubakery_meta['post_title']) ) {
	            $post_title = $noubakery_meta['post_title'];
	        }
	    }

	    if( empty( $post_title ) ){

	        $post_title = get_the_title();

	        if(is_singular('product')){
	        	$post_title = esc_html__('Product', 'noucake');
	        }

	        if ( is_home() ) {
	            $post_title = get_bloginfo('name');
	        }

	        if ( is_search() ) {
	            $post_title = sprintf( esc_html__( 'Search results for: %s', 'noucake' ), get_search_query() );
	        }

	        if ( is_404() ) {
	            $post_title = noubakery_noubakery_cs_get_option('noubakery_404_title', esc_html__( 'Error 404', 'noucake' ));
	        }

	        if ( is_archive() && ! is_search() ) {
	            
	            if ( is_day() ) {
	                $post_title = sprintf( esc_html__( 'Daily Archives: %s', 'noucake' ), get_the_date() );
	            } else if ( is_month() ) {
	                $post_title = sprintf( esc_html__( 'Monthly Archives: %s', 'noucake' ), get_the_date( _x( 'F Y', 'monthly archives date format', 'noucake' ) ) );
	            } elseif ( is_year() ) {
	                $post_title = sprintf( esc_html__( 'Yearly Archives: %s', 'noucake' ), get_the_date( _x( 'Y', 'yearly archives date format', 'noucake' ) ) );
	            } elseif ( is_author() ) {
	                $curauth = get_user_by( 'id', get_query_var( 'author' ) );
	                $post_title   = sprintf( esc_html__( 'All posts by: %s', 'noucake' ), esc_html( $curauth->display_name ) );
	            } elseif ( is_post_type_archive() ) {
	                $post_title = post_type_archive_title( '', false );
	            }else {
	                $post_title = single_cat_title( '', false );
	            }

	        }

	        if(is_tax()){
				$queried_object = get_queried_object();
				$term_id = $queried_object->term_id;
				$meta = noubakery_get_term_meta($term_id, 'noubakery_layout_settings', true);
				
				if(!empty($meta['post_title'])){
					$post_title = $meta['post_title'];
				}
			}

	    }

	    if( $echo ){
	    	echo esc_html($post_title);
	    }

	    return esc_html($post_title);
	}
}

/**
 * Get header style
 *
 * @package Bakery
 * @since 1.0
 * @author nouthemes [nouthemes@gmail.com]
 */

if(!function_exists('noubakery_header_style')){
	function noubakery_header_style() 
	{
	    $header = noubakery_noubakery_cs_get_option('noubakery_header_style', '3');
	    $post_id = noubakery_get_current_id();
	   	
	   	if(is_tax()){
	   		$queried_object = get_queried_object();
			$term_id = $queried_object->term_id;
		    if($term_id){
		        $noubakery_meta = get_term_meta( $term_id, 'noubakery_layout_settings', true );
		        if ( isset($noubakery_meta['header_style']) && !empty($noubakery_meta['header_style']) ) {
		            $header = $noubakery_meta['header_style'];
		        }
		    }
	   	}else{

	   		if(is_archive('product')){
	   			$post_id = get_option('woocommerce_shop_page_id');
	   		}
	   		
	   		if($post_id){
		        $noubakery_meta = get_post_meta( $post_id, 'noubakery_layout_settings', true );
		        if ( isset($noubakery_meta['header_style']) && !empty($noubakery_meta['header_style']) ) {
		            $header = $noubakery_meta['header_style'];
		        }
		    }
	   	}
	    return intval($header);
	}
}

/**
 * Get logo
 *
 * @package Bakery
 * @since 1.0
 * @author nouthemes [nouthemes@gmail.com]
 */

if(!function_exists('noubakery_logo')){
	function noubakery_logo() 
	{
		$post_id = noubakery_get_current_id();
	    $header = noubakery_header_style();
	    $logo_1 = noubakery_theme_option('logo_1', esc_url(NOUBAKERY_IMG.'/logo-1.png'));
	    $logo_2 = noubakery_theme_option('logo_2', esc_url(NOUBAKERY_IMG.'/logo-2.png'));
	    $logo_3 = noubakery_theme_option('logo_3', esc_url(NOUBAKERY_IMG.'/logo-new.png'));
	    $logo_sticky = noubakery_theme_option('logo_sticky', esc_url(NOUBAKERY_IMG.'/logo-2.png'));
	    
	    if(is_category() || is_tag()){
	   		$queried_object = get_queried_object();
			$term_id = $queried_object->term_id;
		    if($term_id){
		        $noubakery_meta = get_term_meta( $term_id, 'noubakery_layout_settings', true );
		        if ( isset($noubakery_meta['logo_1']) && !empty($noubakery_meta['logo_1']) ) {
		            $logo_1 = $noubakery_meta['logo_1'];
		        }
		        if ( isset($noubakery_meta['logo_2']) && !empty($noubakery_meta['logo_2']) ) {
		            $logo_2 = $noubakery_meta['logo_2'];
		        }
		        if ( isset($noubakery_meta['logo_sticky']) && !empty($noubakery_meta['logo_sticky']) ) {
		            $logo_sticky = $noubakery_meta['logo_sticky'];
		        }
		    }
	   	}else{

		    if($post_id){
		        $noubakery_meta = get_post_meta( $post_id, 'noubakery_layout_settings', true );
		        if ( isset($noubakery_meta['logo_1']) && !empty($noubakery_meta['logo_1']) ) {
		            $logo_1 = $noubakery_meta['logo_1'];
		        }
		        if ( isset($noubakery_meta['logo_2']) && !empty($noubakery_meta['logo_2']) ) {
		            $logo_2 = $noubakery_meta['logo_2'];
		        }
		        if ( isset($noubakery_meta['logo_sticky']) && !empty($noubakery_meta['logo_sticky']) ) {
		            $logo_sticky = $noubakery_meta['logo_sticky'];
		        }
		    }
		}    

	    $logo = $logo_1;

	    if($header == '2'){
		  $logo = $logo_2;
		}

	    if($header == '3'){
		  $logo = $logo_3;
		}


	    return array('logo' => $logo, 'logo_sticky' => $logo_sticky);
	}
}


/**
 * Add lazyload
 *
 * @package Bakery
 * @since 1.0
 * @author nouthemes [nouthemes@gmail.com]
 */

if(!function_exists('noubakery_preg_lazyload')){
	function noubakery_preg_lazyload($img_match) {
		$src = noubakery_theme_image_loading_src();
	    $img_replace = $img_match[1] . 'src="'.esc_attr($src).'" data-original' . substr($img_match[2], 3) . $img_match[3];
	    $img_replace = preg_replace('/class\s*=\s*"/i', 'class="lazy ', $img_replace);
	    return wp_kses(
			$img_replace, 
			array(
				'img' => array(
					'src' => array(),
					'class' => array(), 
					'data-original' => array(),
					'width' => array(),
					'height' => array(),
					'alt' => array(), 
					)));
	}
}

/**
 * Get blog style
 *
 * @package Bakery
 * @since 1.0
 * @author nouthemes [nouthemes@gmail.com]
 */

if(!function_exists('noubakery_blog_style')){
	function noubakery_blog_style() 
	{
	    $sidebar = noubakery_noubakery_cs_get_option('noubakery_blog_sidebar', NOUBAKERY_BLOG_DEFAULT_SIDEBAR);
	   	
	   	if(is_category() || is_tag()){
		    $queried_object = get_queried_object();
			$term_id = $queried_object->term_id;
		    if($term_id){
		        $noubakery_meta = get_term_meta( $term_id, 'noubakery_layout_settings', true );
		        if ( isset($noubakery_meta['sidebar']) && !empty($noubakery_meta['sidebar']) ) {
		            $sidebar = $noubakery_meta['sidebar'];
		        }
		    }
		} 

		$post_id = noubakery_get_current_id();
		if($post_id){
			$noubakery_meta = get_post_meta( $post_id, 'noubakery_layout_settings', true );
			if ( !empty($noubakery_meta['sidebar']) ) {
	            $sidebar = $noubakery_meta['sidebar'];
	        }
		}  

		if( !is_active_sidebar('blog-sidebar') ){
			$sidebar = 'hide';
		} 

	    return array('sidebar' => $sidebar);
	}
}


/**
 * Get shop style
 *
 * @package Bakery
 * @since 1.0
 * @author nouthemes [nouthemes@gmail.com]
 */

if(!function_exists('noubakery_shop_style')){
	function noubakery_shop_style() 
	{
	    $sidebar = noubakery_noubakery_cs_get_option('noubakery_shop_sidebar', 'left');
	    $banner = noubakery_noubakery_cs_get_option('noubakery_shop_banner');
	    $view = isset($_SESSION["noubakery_products_view"]) && !empty($_SESSION["noubakery_products_view"]) ? $_SESSION["noubakery_products_view"] : noubakery_noubakery_cs_get_option('noubakery_shop_style', 'gird');   
	   	$col = noubakery_noubakery_cs_get_option('noubakery_shop_grid_col', 3);
	   	if(is_tax()){
		    $queried_object = get_queried_object();
			$term_id = $queried_object->term_id;
		    if($term_id){
		        $noubakery_meta = get_term_meta( $term_id, 'noubakery_layout_settings', true );
		 
		        if ( isset($noubakery_meta['sidebar']) && !empty($noubakery_meta['sidebar']) ) {
		            $sidebar = $noubakery_meta['sidebar'];
		        }
		        if ( isset($noubakery_meta['shop_banner_settings']) && !empty($noubakery_meta['shop_banner_settings']) ) {
		            if(!empty($noubakery_meta['shop_banner'])){$banner = $noubakery_meta['shop_banner'];}
		        }

		        if ( isset($noubakery_meta['shop_grid_col']) && !empty($noubakery_meta['shop_grid_col']) ) {
		            $col = $noubakery_meta['shop_grid_col'];
		        }
		        
		    }
		} 

		$post_id = noubakery_get_current_id();
		if($post_id){
			$noubakery_meta = get_post_meta( $post_id, 'noubakery_layout_settings', true );
			if ( isset($noubakery_meta['sidebar']) && !empty($noubakery_meta['sidebar']) ) {
	            $sidebar = $noubakery_meta['sidebar'];
	        }
		}

		if( !is_active_sidebar('shop-sidebar') ){
			$sidebar = 'hide';
		} 

	    return array(
	    	'col' => $col,
	    	'sidebar' => $sidebar, 
	    	'view' => $view, 
	    	'banner' => $banner, 
	    	'quick_view' => noubakery_noubakery_cs_get_option('noubakery_shop_enable_view'),
	    	'wishlist' => noubakery_noubakery_cs_get_option('noubakery_shop_enable_wishlist'),
	    	'compare' => noubakery_noubakery_cs_get_option('noubakery_shop_enable_compare'),
	    	'add_to_cart' => noubakery_noubakery_cs_get_option('noubakery_shop_enable_cart'),
	    	);
	}
}


/**
* Function Comment callback
* 
* @author nouthemes [nouthemes@gmail.com]
* @since 1.0
* @code Nam
*/
function noubakery_comment_callback( $comment, $args, $depth ){
    global $comment_depth;
    $author = get_comment_author( get_comment_ID() );
    $class_cooment = ($comment_depth > 0) ? 'ps-comment__replay' : '';
    ?>
    <div <?php comment_class($class_cooment); ?> id="comment-<?php comment_ID() ?>" data-id="<?php comment_ID() ?>">
        <div class="ps-comment-box">
            <div class="ps-comment-box__thumbnail">
            	<?php echo get_avatar($comment, 80); ?>
            </div>
            <div class="ps-comment-box__content">
              <h4><?php echo esc_html( $author );?><span><?php printf( _x( '%s ago', '%s = human-readable time difference', 'noucake' ), human_time_diff( get_comment_time( 'U' ), current_time( 'timestamp' ) ) ); ?></span></h4>
              <?php comment_text() ?>
              <?php comment_reply_link(array_merge( $args, array('reply_text' => '<i class="fa fa-angle-right"></i>'.esc_html__('Reply', 'noucake'), 'add_below' => 'comment', 'depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
            </div>
        </div>
    <?php
}

/**
* Function Comment callback for product
* 
* @author nouthemes [nouthemes@gmail.com]
* @since 1.0
* @code Nam
*/
function noubakery_comment_callback_product( $comment, $args, $depth ){
    global $comment_depth;
    $author = get_comment_author( get_comment_ID() );
    ?>
    <div <?php comment_class('ps-review-box'); ?> id="comment-<?php comment_ID() ?>" data-id="<?php comment_ID() ?>">
        <div class="ps-review-box__thumbnail"><?php echo get_avatar($comment, 80); ?></div>
        <div class="ps-review-box__content">
            <header>
            <?php 
            $rating = intval( get_comment_meta( $comment->comment_ID, 'rating', true ) );
			if ( $rating && get_option( 'woocommerce_enable_review_rating' ) === 'yes' ) { ?>
	            <select class="ps-rating">
	                <option value="0" <?php selected($rating, '0');?>>0</option>
	                <option value="1" <?php selected($rating, '1');?>>1</option>
	                <option value="2" <?php selected($rating, '2');?>>2</option>
	                <option value="3" <?php selected($rating, '3');?>>3</option>
	                <option value="4" <?php selected($rating, '4');?>>4</option>
	                <option value="5" <?php selected($rating, '5');?>>5</option>
	            </select>
	        <?php }?>

              <p><?php esc_html_e('By', 'noucake');?> <?php echo esc_html( $author );?> - <?php comment_date(get_option('date_format'));?></p>
            </header>
            <?php comment_text() ?>
            <?php comment_reply_link(array_merge( $args, array('reply_text' => '<i class="fa fa-angle-right"></i> '.esc_html__('Reply', 'noucake'), 'add_below' => 'comment', 'depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
        </div>
    <?php
}


/**
* Get images products
* 
* @author nouthemes [nouthemes@gmail.com]
* @since 1.0
* @code Nam
*/
function noubakery_product_images( $product_id ){
    
    $ids = array();

	if(has_post_thumbnail($product_id)){
		$ids[] = get_post_thumbnail_id($product_id);
	}

    if(class_exists('Woocommerce')){
    	$product = wc_get_product($product_id);
    	$galleries = $product->get_gallery_image_ids();
		$ids = array_merge($ids, $galleries);
		try {
			if($product->is_type( 'variable' )){
				$product = new WC_Product_Variable( $product_id );
				$variations = $product->get_available_variations();
				foreach ( $variations as $variation ) {  
					if(isset($variation['image_id']) && $variation['image_id'] > 0){
						$ids[] = $variation['image_id'];
					}
				}
			}
		} catch (\Throwable $th) {
			//throw $th;
		}
    }
	
    return array_unique($ids);
}

function noubakery_contact_block(){
	$current_id = noubakery_get_current_id();
	if($current_id){
		$meta = get_post_meta($current_id, 'noubakery_layout_settings', true);
		if(!empty($meta['contact'])){
			foreach ($meta['contact'] as $key => $value) {
				?>
				<div class="ps-contact__block">
	                <?php if(!empty($value['title'])):?><h4><?php echo esc_html($value['title']);?></h4><?php endif;?>
	                <?php if(!empty($value['address'])):?><p><strong><?php echo esc_html($value['address']);?></strong></p><?php endif;?>
	                <?php if(!empty($value['email'])):?><p><i class="fa fa-envelope-o"></i><?php echo esc_html($value['email']);?></p><?php endif;?>
	                <?php if(!empty($value['phone'])):?><p><i class="fa fa-phone"></i><?php echo esc_html($value['phone']);?></p><?php endif;?>
                    <ul class="ps-contact__social">
                      	<?php if(!empty($value['fb'])):?><li><a href="<?php echo esc_url($value['fb']);?>" target="_blank"><i class="fa fa-facebook"></i></a></li><?php endif;?>
                      	<?php if(!empty($value['twitter'])):?><li><a href="<?php echo esc_url($value['twitter']);?>" target="_blank"><i class="fa fa-twitter"></i></a></li><?php endif;?>
                      	<?php if(!empty($value['tiktok'])):?><li><a href="<?php echo esc_url($value['tiktok']);?>" target="_blank"><i><svg xmlns="http://www.w3.org/2000/svg" width="14" height="14" fill="#b2b2b2" viewBox="0 0 448 512"><path d="M448 209.9a210.1 210.1 0 0 1 -122.8-39.3V349.4A162.6 162.6 0 1 1 185 188.3V278.2a74.6 74.6 0 1 0 52.2 71.2V0l88 0a121.2 121.2 0 0 0 1.9 22.2h0A122.2 122.2 0 0 0 381 102.4a121.4 121.4 0 0 0 67 20.1z"></path></svg></i>
</a></li><?php endif;?>
						<?php if(!empty($value['instagram'])):?><li><a href="<?php echo esc_url($value['instagram']);?>" target="_blank"><i class="fa fa-instagram"></i></a></li><?php endif;?>
                      	<?php if(!empty($value['rss'])):?><li><a href="<?php echo esc_url($value['rss']);?>" target="_blank"><i class="fa fa-rss"></i></a></li><?php endif;?>
                    </ul>
	            </div>
				<?php
			}
		}
	}
}

function noubakery_sticky_post_icon(){
	$icon = noubakery_noubakery_cs_get_option('noubakery_sticky_icon', 'fa fa-paperclip');
	echo '<i class="'.esc_attr($icon).'" aria-hidden="true" title="'.esc_html__('Sticky post', 'noucake').'"></i>';
}


function noubakery_single_product_settings(){
	$layout = noubakery_noubakery_cs_get_option('noubakery_product_layout', '1');
	$related_type = noubakery_noubakery_cs_get_option('noubakery_product_related_type', 'related');
	$title = noubakery_noubakery_cs_get_option('noubakery_shop_related_title');
	$desc = noubakery_noubakery_cs_get_option('noubakery_shop_related_desc');
	$form_title = noubakery_noubakery_cs_get_option('noubakery_shop_form_title');
	$form_desc = noubakery_noubakery_cs_get_option('noubakery_shop_form_desc');
	$lightbox = noubakery_noubakery_cs_get_option('noubakery_shop_enable_single_lightbox', '1');

	$post_id = noubakery_get_current_id();
	if($post_id){
		$noubakery_meta = get_post_meta( $post_id, 'noubakery_layout_settings', true );
		if ( isset($noubakery_meta['layout']) && !empty($noubakery_meta['layout']) ) {
            $layout = $noubakery_meta['layout'];
        }
        if ( isset($noubakery_meta['product_related_type']) && !empty($noubakery_meta['product_related_type']) ) {
            $related_type = $noubakery_meta['product_related_type'];
        }
        if ( isset($noubakery_meta['shop_related_title']) && !empty($noubakery_meta['shop_related_title']) ) {
            $title = $noubakery_meta['shop_related_title'];
        }
        if ( isset($noubakery_meta['shop_related_desc']) && !empty($noubakery_meta['shop_related_desc']) ) {
            $desc = $noubakery_meta['shop_related_desc'];
        }
        if ( isset($noubakery_meta['shop_form_title']) && !empty($noubakery_meta['shop_form_title']) ) {
            $form_title = $noubakery_meta['shop_form_title'];
        }
        if ( isset($noubakery_meta['shop_form_desc']) && !empty($noubakery_meta['shop_form_desc']) ) {
            $form_desc = $noubakery_meta['shop_form_desc'];
        }
	}

	return apply_filters('noubakery_single_product_settings', array('layout' => $layout, 'related_type' => $related_type, 'title' => $title, 'desc' => $desc, 'form_title' => $form_title, 'form_desc' => $form_desc, 'lightbox' => $lightbox ), $post_id);
}

function woocommerce_template_loop_product_title() {
	echo get_the_title();
}

function noubakery_product_per_page(){
	$items = noubakery_theme_option('product_per_page', 9);
	if($items == 'custom'){
		$items = noubakery_theme_option('product_per_page_custom', 9);
	}
	return $items;
}

if(!function_exists('noubakery_esc')){
	function noubakery_esc($content){
		return $content;
	}
}

if(!function_exists('noubakery_product_video')){
	function noubakery_product_video(){
		global $post;
		$video = get_post_meta($post->ID, '_product_video', true);
		$video_url = '';
		$video_id = '';
		$video_img = '';
		if(!empty($video['url'])){
			preg_match("#(?<=v=)[a-zA-Z0-9-]+(?=&)|(?<=v\/)[^&\n]+(?=\?)|(?<=v=)[^&\n]+|(?<=youtu.be/)[^&\n]+#", $video['url'], $matches);
			$video_id = $matches;
			if(isset($video_id[0]) && !empty($video_id[0])){
				$protocol = is_ssl() ? 'https' : 'http';
				$video_url = $protocol.'://www.youtube.com/watch?v='.$video_id[0];
				$video_img = $protocol.'://img.youtube.com/vi/'.$video_id[0].'/maxresdefault.jpg';
			}
		}

		return array('url' => $video_url, 'img' => $video_img);
	}
}

/**
* Retrieve a post given its title.
*
* @uses $wpdb
*
* @param string $post_title Page title
* @param string $post_type post type ('post','page','any custom type')
* @param string $output Optional. Output type. OBJECT, ARRAY_N, or ARRAY_A.
* @return mixed
*/
if(!function_exists('noubakery_get_post_by_title')){
	function noubakery_get_post_by_title($page_title, $post_type ='post' , $output = OBJECT) {
		global $wpdb;
		$post = $wpdb->get_var( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE post_title = %s AND post_type= %s", $page_title, $post_type));
		if ( $post ){
			return get_post($post, $output);
		}
		return null;
	}
}


/**
* Get product variable image
* 
* @author nouthemes [nouthemes@gmail.com]
* @since 1.0
* @code Nam
*/
function noubakery_variable_images( $product_id ){
    
    $ids = array();
    if(class_exists('Woocommerce')){
    	$product = wc_get_product($product_id);
		try {
			if($product->is_type( 'variable' )){
				$product = new WC_Product_Variable( $product_id );
				$variations = $product->get_available_variations();
				foreach ( $variations as $variation ) {  
					if(isset($variation['image_id']) && $variation['image_id'] > 0){
						$ids[$variation['variation_id']] = $variation['image_id'];
					}
				}
			}
		} catch (\Throwable $th) {
			//throw $th;
		}
    }
	
    return $ids;
}

function noubakery_do_shortcode($content){
	return wp_kses_post(do_shortcode($content));
}
?>