<?php
/**
 * Order Customer Details
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/order/order-details-customer.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 8.7.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Action hook fired after an address in the order customer details.
 *
 * @param string $address_type Type of address (billing or shipping).
 * @param WC_Order $order Order object.
 * @since 8.7.0
 */
do_action('woocommerce_order_details_after_customer_address', 'billing', $order);


$show_shipping = ! wc_ship_to_billing_address_only() && $order->needs_shipping_address();
?>

<section class="woocommerce-customer-details">

	<h2><?php esc_html_e( 'Customer details', 'noucake' ); ?></h2>

	<table class="woocommerce-table woocommerce-table--customer-details shop_table customer_details">

		<?php if ( $order->get_customer_note() ) : ?>
			<tr>
				<th><?php esc_html_e( 'Note:', 'noucake' ); ?></th>
				<td><?php echo wptexturize( $order->get_customer_note() ); ?></td>
			</tr>
		<?php endif; ?>

		<?php if ( $order->get_billing_email() ) : ?>
			<tr>
				<th><?php esc_html_e( 'Email:', 'noucake' ); ?></th>
				<td><?php echo esc_html( $order->get_billing_email() ); ?></td>
			</tr>
		<?php endif; ?>

		<?php if ( $order->get_billing_phone() ) : ?>
			<tr>
				<th><?php esc_html_e( 'Phone:', 'noucake' ); ?></th>
				<td><?php echo esc_html( $order->get_billing_phone() ); ?></td>
			</tr>
		<?php endif; ?>

		<?php do_action( 'woocommerce_order_details_after_customer_details', $order ); ?>

	</table>

	<?php if ( $show_shipping ) : ?>

	<section class="woocommerce-columns woocommerce-columns--2 woocommerce-columns--addresses col2-set addresses">

		<div class="woocommerce-column woocommerce-column--1 woocommerce-column--billing-address col-1">

			<?php endif; ?>

			<h3 class="woocommerce-column__title"><?php esc_html_e( 'Billing address', 'noucake' ); ?></h3>

			<address>
				<?php echo noubakery_esc(( $address = $order->get_formatted_billing_address() ) ? $address : __( 'N/A', 'noucake' )); ?>
			</address>

			<?php if ( $show_shipping ) : ?>

		</div><!-- /.col-1 -->

		<div class="woocommerce-column woocommerce-column--2 woocommerce-column--shipping-address col-2">

			<h3 class="woocommerce-column__title"><?php esc_html_e( 'Shipping address', 'noucake' ); ?></h3>

			<address>
				<?php echo noubakery_esc(( $address = $order->get_formatted_shipping_address() ) ? $address : __( 'N/A', 'noucake' )); ?>
			</address>

            <?php
            /**
             * Action hook fired after an address in the order customer details.
             *
             * @since 8.7.0
             * @param string $address_type Type of address (billing or shipping).
             * @param WC_Order $order Order object.
             */
            do_action( 'woocommerce_order_details_after_customer_address', 'shipping', $order );
            ?>

		</div><!-- /.col-2 -->

	</section><!-- /.col2-set -->

	<?php endif; ?>

</section>
