<?php
/**
 * Single Product Meta
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/meta.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $post, $product;


try{
	$product_cat = get_the_terms( $post->ID, 'product_cat' );
	if ( $product_cat && ! is_wp_error( $product_cat ) ){
		$cat_count = sizeof( $product_cat );
	}else{
		$cat_count = 0;
	}

	$product_tag = get_the_terms( $post->ID, 'product_tag' );
	if ( $product_tag && ! is_wp_error( $product_tag ) ){
		$tag_count = sizeof( $product_tag );
	}else{
		$tag_count = 0;
	}
	
} catch (exception $e) {
	$cat_count = 0;
	$tag_count = 0;
}

$stock = wc_get_stock_html( $product );
if(empty($stock)){
	$stock = esc_html__('In Stock', 'noucake');
}

$stock_enable = noubakery_theme_option('product_meta_enable_stock');
$tags_enable = noubakery_theme_option('product_meta_enable_tags');
$cat_enable = noubakery_theme_option('product_meta_enable_category');
$sku_enable = noubakery_theme_option('product_meta_enable_sku');
?>

<div class="ps-product__meta">

	<?php do_action( 'woocommerce_product_meta_start' ); ?>

	<?php if(!empty($stock_enable)):?>
	<p><span><?php esc_html_e('Availability', 'noucake');?>: </span> <?php echo noubakery_esc($product->is_in_stock() ? $stock : esc_html__('Out Of Stock', 'noucake')); ?></p>
	<?php endif; ?>

	<?php if(!empty($sku_enable)):?>
		<?php if ( wc_product_sku_enabled() && ( $product->get_sku() || $product->is_type( 'variable' ) ) ) : ?>
		<p class="panel-product-line panel-product-info">	
			<span class="panel-product-label"><?php esc_html_e( 'SKU:', 'noucake' ); ?></span> <span class="sku-for-default sku-value"><?php echo noubakery_esc(( $sku = $product->get_sku() ) ? $sku : __( 'N/A', 'noucake' )); ?></span><span class="sku-for-varian sku-value"></span>
		</p>	

		<?php endif; ?>
	<?php endif; ?>

	<?php if(!empty($cat_enable)):?>
	<?php echo wc_get_product_category_list( $product->get_id(), ', ', '<p class="category"><span>' . _n( 'Category:', 'Categories:', $cat_count, 'noucake' ) . '</span> ', '</p>' ); ?>
	<?php endif; ?>

	<?php if(!empty($tags_enable)):?>
	<?php echo wc_get_product_tag_list( $product->get_id(), ', ', '<p class="category"><span>' . _n( 'Tag:', 'Tags:', $tag_count, 'noucake' ) . '</span> ', '</p>' ); ?>
	<?php endif; ?>

	<?php do_action( 'woocommerce_product_meta_end' ); ?>

</div>
