<?php
/**
 * Related Products
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/related.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.9.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $product, $woocommerce_loop;
$posts_per_page = get_option('posts_per_page');
if ( empty( $product ) || ! $product->exists() ) {
	return;
}

$single_settings = noubakery_single_product_settings();
$shop_settings = noubakery_shop_style();

$args = array('post_type' => 'product',
		'post_status'         => 'publish',
		'ignore_sticky_posts'  => 1,
		'no_found_rows'        => 1,
		'posts_per_page'       => $posts_per_page,
		'orderby'              => $orderby,);

if($single_settings['related_type'] == 'bestsale'){
	$args['meta_key'] = 'total_sales';
	$args['orderby'] = 'meta_value_num'; 
}elseif($single_settings['related_type'] == 'sale'){
	$product_ids_on_sale    = wc_get_product_ids_on_sale();
	$product_ids_on_sale[]  = 0;
	$args['post__in'] = $product_ids_on_sale;
}elseif($single_settings['related_type'] == 'featured'){
	$product_visibility_term_ids = wc_get_product_visibility_term_ids();
	$args['tax_query'][] = array(
		'taxonomy' => 'product_visibility',
		'field'    => 'term_taxonomy_id',
		'terms'    => $product_visibility_term_ids['featured'],
	);
}else{

	if ( $related = wc_get_related_products($product->get_id()) ) {
		$args['post__in']  = $related;
	}
}

$args['post__not_in'] = array( $product->get_id() );
$products  = new WP_Query( $args );
if ( $products->have_posts() ) : ?>
<section class="ps-section ps-section--best-seller pt-40 pb-100">
    <div class="container">
    	<?php if(!empty($single_settings['desc']) || !empty($single_settings['title'])):?>
    	<div class="ps-section__header text-center mb-50">
            <?php if(!empty($single_settings['desc'])):?><h4 class="ps-section__top"><?php echo esc_html($single_settings['desc']);?></h4><?php endif;?>
            <?php if(!empty($single_settings['title'])):?><h3 class="ps-section__title ps-section__title--full"><?php echo esc_html($single_settings['title']);?></h3><?php endif;?>
        </div>
        <?php endif;?>

		<div class="ps-section__content">
			<div class="owl-slider owl-slider--best-seller" data-owl-auto="true" data-owl-loop="true" data-owl-speed="100000" data-owl-gap="30" data-owl-nav="true" data-owl-dots="false" data-owl-animate-in="" data-owl-animate-out="" data-owl-item="4" data-owl-item-xs="1" data-owl-item-sm="2" data-owl-item-md="3" data-owl-item-lg="4" data-owl-nav-left="&lt;i class=&quot;ps-icon--back&quot;&gt;&lt;/i&gt;" data-owl-nav-right="&lt;i class=&quot;ps-icon--next&quot;&gt;&lt;/i&gt;">

				<?php 
				while ( $products->have_posts() ) : $products->the_post(); 
				$product = wc_get_product(get_the_ID());
				?>
				<div <?php post_class('ps-product');?>>
	                <div class="ps-product__thumbnail">
	                	<?php woocommerce_show_product_loop_sale_flash();?>
	      				<a class="ps-product__overlay" href="<?php the_permalink();?>"></a>
	      				<?php echo noubakery_post_thumbnail(get_the_ID(), 'noubakery_262x283');?>

	                  	<ul class="ps-product__action">
		                    <?php if(!empty($shop_settings['quick_view'])):?>
						        <li><a data-product_id="<?php echo esc_attr($product->get_id());?>" class="product-quickview popup-modal" href="#quickview-modal" data-effect="mfp-zoom-out" data-tooltip="<?php esc_html_e('View', 'noucake');?>"><i class="ps-icon--search"></i></a></li>
						    <?php endif;?>

					        <?php if(!empty($shop_settings['wishlist'])):?>
						        <li><a class="product-wishlist" data-product_id="<?php echo esc_attr($product->get_id());?>" href="#" data-tooltip="<?php esc_html_e('Add to wishlist', 'noucake');?>"><i class="ps-icon--heart"></i></a></li>
						    <?php endif;?>

					        <?php if(!empty($shop_settings['compare'])):?>
						        <li><a class="product-compare" data-product_id="<?php echo esc_attr($product->get_id());?>" href="#" data-tooltip="<?php esc_html_e('Compare', 'noucake');?>"><i class="ps-icon--reload"></i></a></li>
						    <?php endif;?>

						    <?php if(!empty($shop_settings['add_to_cart'])):?>
					        	<li><?php woocommerce_template_loop_add_to_cart();?></li>
					        <?php endif;?>	
	                  	</ul>
	                </div>
	                <div class="ps-product__content">
	                	<a class="ps-product__title" href="<?php the_permalink();?>"><?php the_title();?></a>
	                  	<div class="ps-product__category"><?php echo wp_kses_post(wc_get_product_category_list( $product->get_id(), '', '', '' )); ?></div>
	                  	<?php woocommerce_template_loop_rating();?>
	        			<?php woocommerce_template_loop_price();?>
	                </div>
	            </div>
				<?php endwhile; // end of the loop. ?>

			</div>

		</div>
	</div>
</section>

<?php endif;

wp_reset_postdata();
